@@ -18,12 +18,12 @@ DOCR_BEGIN_NAMESPACE
 PaddleOCRApp::PaddleOCRApp()
 {
 #ifndef QT_NO_DEBUG
-    currentPath = OCR_MODEL_DIR;
+    currentPath = QString("%0/v2/").arg(OCR_MODEL_DIR);
 #else
     QString fullPath;
     auto xdgDirs = QProcessEnvironment::systemEnvironment().value("XDG_DATA_DIRS").split(':');
     for (auto &xdgDir : xdgDirs) {
-        fullPath = xdgDir + '/' + OCR_MODEL_DIR;
+        fullPath = QString("%0/%1/v2/").arg(xdgDir).arg(OCR_MODEL_DIR);
         if (QFile::exists(fullPath)) {
             currentPath = fullPath;
             break;
@@ -31,7 +31,7 @@ PaddleOCRApp::PaddleOCRApp()
     }
 
     if (currentPath.isEmpty()) {
-        fullPath = "/usr/share/" OCR_MODEL_DIR;
+        fullPath = QString("/usr/share/%0/v2/").arg(OCR_MODEL_DIR);
         if (QFile::exists(fullPath)) {
             currentPath = fullPath;
         } else {
@@ -39,6 +39,10 @@ PaddleOCRApp::PaddleOCRApp()
         }
     }
 #endif
+// sw 64，OpenCV 多线程会导致崩溃，先做规避处理
+#if defined(__sw_64__) || defined(__mips__)
+    cv::setNumThreads(0);
+#endif
 }
 
 PaddleOCRApp::~PaddleOCRApp()
@@ -136,7 +140,6 @@ void PaddleOCRApp::initNet()
             recNet->opt.use_vulkan_compute = true;
         }
 #endif
-
         recNet->load_param_bin((recModelPathPrefix + paramSuffix).toStdString().c_str());
         recNet->load_model((recModelPathPrefix + binSuffix).toStdString().c_str());
     }
@@ -185,15 +188,12 @@ PaddleOCRApp::detect(const cv::Mat &src, float thresh, float boxThresh, float un
     float ratio_w = float(resizeW) / float(src.cols);
     cv::Mat resize_img;
     cv::resize(src, resize_img, cv::Size(resizeW, resizeH));
-
     ncnn::Mat in_pad = ncnn::Mat::from_pixels(resize_img.data, ncnn::Mat::PIXEL_RGB, resizeW, resizeH);
-
     const float meanValues[3] = {0.485f * 255, 0.456f * 255, 0.406f * 255};
     const float normValues[3] = {1.0f / 0.229f / 255.0f, 1.0f / 0.224f / 255.0f, 1.0f / 0.225f / 255.0f};
 
     in_pad.substract_mean_normalize(meanValues, normValues);
     ncnn::Extractor extractor = detNet->create_extractor();
-
     extractor.input(0, in_pad);
     ncnn::Mat out;
     extractor.extract(detNet->output_indexes()[0], out);
@@ -224,24 +224,27 @@ PaddleOCRApp::detect(const cv::Mat &src, float thresh, float boxThresh, float un
     cv::Mat pred_map(out.h, out.w, CV_32F, static_cast<float *>(pred.data()));
 
     const float threshold = thresh * 255.0f;
-    cv::Mat bit_map;
-    cv::threshold(cbuf_map, bit_map, static_cast<double>(threshold), 255, cv::THRESH_BINARY);
-    cv::Mat dilation_map;
-    cv::Mat dila_ele = cv::getStructuringElement(cv::MORPH_RECT, cv::Size(2, 2));
-    cv::dilate(bit_map, dilation_map, dila_ele);
+    cv::Mat mask;
+    {
+        cv::Mat bit_map;
+        cv::threshold(cbuf_map, bit_map, static_cast<double>(threshold), 255, cv::THRESH_BINARY);
+        cv::Mat dilation_map;
+        cv::Mat dila_ele = cv::getStructuringElement(cv::MORPH_RECT, cv::Size(2, 2));
+        cv::dilate(bit_map, dilation_map, dila_ele);
+        mask = dilation_map;
+    }
 
     if (needBreak) {
         return std::vector<std::vector<std::vector<int>>>();
     }
 
-    auto result = postProcessor.BoxesFromBitmap(pred_map, dilation_map, boxThresh, unclipRatio, false);
+    auto result = postProcessor.BoxesFromBitmap(pred_map, mask, boxThresh, unclipRatio, false, false);
 
     if (needBreak) {
         return std::vector<std::vector<std::vector<int>>>();
     }
 
     result = postProcessor.FilterTagDetRes(result, ratio_h, ratio_w, src);
-
     return result;
 }
 
@@ -252,6 +255,7 @@ std::pair<std::string, std::vector<int>> PaddleOCRApp::ctcDecode(const std::vect
     int currentSize = 0;
     int status = 0;
     size_t lastIndex = 0;
+
     for (int i = 0; i < h; i++) {
         size_t maxIndex = 0;
         maxIndex = utilityTool.argmax(recNetOutputData.begin() + i * w, recNetOutputData.begin() + i * w + w);
@@ -306,33 +310,33 @@ void PaddleOCRApp::rec(const std::vector<cv::Mat> &detectImg)
             continue;
         }
 
-        //输入图片固定高度32
-        float ratio = static_cast<float>(detectImg[i].cols) / static_cast<float>(detectImg[i].rows);
-        int imgW = static_cast<int>(32 * ratio);
-        int resize_w;
-        if (ceilf(32 * ratio) > imgW)
-            resize_w = imgW;
-        else
-            resize_w = static_cast<int>(ceilf(32 * ratio));
-
         cv::Mat stdMat;
-        cv::resize(detectImg[i], stdMat, cv::Size(resize_w, 32), 0, 0, cv::INTER_LINEAR);
-        cv::copyMakeBorder(stdMat, stdMat, 0, 0, 0, int(imgW - stdMat.cols), cv::BORDER_CONSTANT, {127, 127, 127});
+        {
+            //输入图片固定高度32
+            float ratio = static_cast<float>(detectImg[i].cols) / static_cast<float>(detectImg[i].rows);
+            int imgW = static_cast<int>(32 * ratio);
+            int resize_w;
+            if (ceilf(32 * ratio) > imgW)
+                resize_w = imgW;
+            else
+                resize_w = static_cast<int>(ceilf(32 * ratio));
+
+            cv::resize(detectImg[i], stdMat, cv::Size(resize_w, 32), 0, 0, cv::INTER_LINEAR);
+            cv::copyMakeBorder(stdMat, stdMat, 0, 0, 0, int(imgW - stdMat.cols), cv::BORDER_CONSTANT, {127, 127, 127});
+        }
 
         float realRatio = static_cast<float>(stdMat.cols) / detectImg[i].cols;
-
         if (needBreak) {
             continue;
         }
 
+        //stdMat HWC,BGR
         ncnn::Mat input = ncnn::Mat::from_pixels(stdMat.data, ncnn::Mat::PIXEL_RGB, stdMat.cols, stdMat.rows);
         const float mean_vals[3] = {127.5, 127.5, 127.5};
         const float norm_vals[3] = {1.0f / 127.5f, 1.0f / 127.5f, 1.0f / 127.5f};
         input.substract_mean_normalize(mean_vals, norm_vals);
-
         auto outIndexes = recNet->output_indexes();
         ncnn::Extractor extractor = recNet->create_extractor();
-
         if (recNet->opt.use_vulkan_compute) {
             if (maxThreadsUsed > 1 && i % maxThreadsUsed != 1) {
                 extractor.set_vulkan_compute(false);
@@ -351,13 +355,15 @@ void PaddleOCRApp::rec(const std::vector<cv::Mat> &detectImg)
         std::vector<float> recNetOutputData(floatArray, floatArray + out.h * out.w);
 
         auto ctcResult = ctcDecode(recNetOutputData, out.h, out.w);
-
-        allResultVec[i] = ctcResult.first;
-        boxesResult[i] = ctcResult.first.c_str();
-        auto box = allTextBoxes[i];
         auto baseSize = ctcResult.second;
-        auto currentCharBox = lengthToBox(baseSize, allTextBoxes[i].points[0], box.points[2].y() - box.points[0].y(), realRatio);
-        allCharBoxes[i] = currentCharBox;
+        auto box = allTextBoxes[i];
+        auto currentCharBox = lengthToBox(baseSize, box.points[0], box.points[2].y() - box.points[0].y(), realRatio);
+#pragma omp critical
+        {
+            allResultVec[i] = ctcResult.first;
+            boxesResult[i] = ctcResult.first.c_str();
+            allCharBoxes[i] = currentCharBox;
+        }
 
         if (needBreak) {
             continue;
@@ -452,12 +458,11 @@ bool PaddleOCRApp::analyze()
     initNet();
 
     auto image = imageCache.convertToFormat(QImage::Format_RGB888);
-    image = image.rgbSwapped();
-    cv::Mat matrix(image.height(), image.width(), CV_8UC3, image.bits(), image.bytesPerLine());
+    image = image.rgbSwapped(); //BGR
+    cv::Mat matrix(image.height(), image.width(), CV_8UC3, image.bits(), image.bytesPerLine()); //HWC,BGR
 
     do {
         auto boxes = detect(matrix, 0.3f, 0.5f, 1.6f);
-
         if (needBreak) {
             break;
         }
